pg.ddx.io pgsql-interfaces@postgresql.org mailing list archive
help / color / mirror / Atom feedSlow down on Import
2+ messages / 2 participants
[nested] [flat]
* Slow down on Import
@ 2000-01-12 16:45 Rolf Lüttecke <rluettecke@gcd.de>
0 siblings, 1 reply; 2+ messages in thread
From: Rolf Lüttecke @ 2000-01-12 16:45 UTC (permalink / raw)
To: pgsql-interfaces
Hi folks,
first some techn. data: SNI-Primergy w/ PII-333, 128Meg and
SCSI-devices, Linux 2.0.36
The following strange behaviour comes up since upgrading to
version 6.5.3 + FreeFile-Patch (hi Tom):
When re-importing a dumped database the job is normally done
in roundabout 8 seconds. When you drop the database and
repeat the step a few times, the speed slows down to at least
1.5 minutes.
Example:
# for i in 1 2 3 4 5
# do
# destroydb xyz
# createdb xyz
# time psql xyz < ./import.db (small table / 10.000 rows)
# (output from time: 8.2 seconds up to 1.5 minutes)
# done
There is no additional load on that machine. The main application
(MS-Access w/ ODBC xx.0006) seems sleeping during database-
search - so we tried to figure out the problem and made at least
the above test directly on that machine. Last hint: A complete
copy from "/opt/pgsql" transferred to a another machine shows
the same problem.
What´s wrong? Any ideas?
Regards
-Rolf
^ permalink raw reply [nested|flat] 2+ messages in thread
* Re: [INTERFACES] Slow down on Import
@ 2000-01-16 05:24 Tom Lane <tgl@sss.pgh.pa.us>
parent: Rolf Lüttecke <rluettecke@gcd.de>
0 siblings, 0 replies; 2+ messages in thread
From: Tom Lane @ 2000-01-16 05:24 UTC (permalink / raw)
To: Rolf Lüttecke <rluettecke@gcd.de>; +Cc: pgsql-interfaces
"=?iso-8859-1?Q?Rolf_L=FCttecke?=" <rluettecke@gcd.de> writes:
> # for i in 1 2 3 4 5
> # do
> # destroydb xyz
> # createdb xyz
> # time psql xyz < ./import.db (small table / 10.000 rows)
> # (output from time: 8.2 seconds up to 1.5 minutes)
> # done
Hmm. I tried to reproduce this behavior, but didn't see it on either
6.5.* or current sources. Does anyone else see it?
regards, tom lane
^ permalink raw reply [nested|flat] 2+ messages in thread
end of thread, other threads:[~2000-01-16 05:24 UTC | newest]
Thread overview: 2+ messages (download: mbox mbox.gz follow: Atom feed)
-- links below jump to the message on this page --
2000-01-12 16:45 Slow down on Import Rolf Lüttecke <rluettecke@gcd.de>
2000-01-16 05:24 ` Tom Lane <tgl@sss.pgh.pa.us>
This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox